==> jool_4.1.7.orig.tar.gz: jool-4.1.7/README.md <==
# [Jool](https://www.jool.mx)

An [SIIT and a NAT64](https://www.jool.mx/en/intro-xlat.html) for Linux.

> Note!
> 
> Jool's website is hosted in two separate domains simultaneously:
> 
> - https://www.jool.mx (Might be outdated for a few days at a time)
> - https://nicmx.github.io/Jool ([Used](https://github.com/isaacs/github/issues/354#event-5407912041) to be unavailable from IPv6.)

## Documentation

[See here](https://www.jool.mx/en/documentation.html). You can also [generate the docs yourself](docs/).

You might also want to see [contact info](https://www.jool.mx/en/contact.html).

## Credits

### NIC-Mx

* Ing. Jorge Cano Puente
* Ing. Sergio Adrián Casas Fernández - iam@sergio-casas.com
* Ing. Julio Cesar Cossio de Robles
* Ing. [Daniel Hernández Félix](https://github.com/dhfelix) - dhernandez@nic.mx
* Ing. [Alberto Leiva Popper](https://github.com/ydahhrk)
* Ing. Cristóbal Alfonso de León Benítez - cristobal.alfonso14@gmail.com
* Ing. Roberto Olivas Alarcón - roaguns@gmail.com
* Edgar Martín Rodríguez Bernal - edgarmrb_95@hotmail.com

### ITESM representatives

* Dr. Juan Arturo Nolazco - jnolazco@itesm.mx
* Ing. Martha Sordia - msordia@itesm.mx

### ITESM students

* [Abraham Baez](https://github.com/basuam) - basuam@gmail.com
* [Adrian González](https://github.com/Adrian2112) - bernardogzzf@gmail.com
* Alan Villela López - avillop@gmail.com
* [Angel Cazares](https://github.com/legionAngel) - angel.cazares@live.com
* Armando Cifuentes González - 3ncifuentesg@gmail.com
* [David Valenzuela](https://github.com/davidvrdz) - david.valenzuela.88@gmail.com
* Ing. Elvia Patricia Barrón Cano - epatybarron@gmail.com
* [Gabriel Chavez](https://github.com/chavezgu) - gabrielchavez02@gmail.com
* Jose Vicente Ramirez - pepermz@gmail.com
* [Juan Antonio Osorio](https://github.com/JAORMX) - jaosorior@gmail.com
* Juan Francisco Barragán Cantú - p.cantu12@gmail.com
* [Luis Fernando Hinojosa](https://github.com/luion) - lf.hinojosa@gmail.com
* Manuel Aude - dormam@gmail.com
* Mario Gerardo Trevinho - mario_tc88@hotmail.com
* [Miguel Alejandro González](https://github.com/magg) - maggonzz@gmail.com
* [Nixa Jayu Gpe Rodríguez Dagnino](https://github.com/NixaDagnino)
* [Ramiro Nava](https://github.com/ramironava) - ramironava@gmail.com
* [Roberto Aceves](https://github.com/robertoaceves) - roberto.aceves@gmail.com
* [Roberto Martínez Beltrán](https://github.com/ryuzak) - robmabe.92@gmail.com

### Special Thanks (contributing users)

* [airsnail](https://github.com/airsnail)
* [Andreas Urke](https://github.com/arurke)
* Andreas Rammhold
* [Dan Lüdtke](https://www.danrl.com)
* Eric Gamess
* [Hidekazu Tadokoro](https://github.com/tadokoro)
* [ipclouds](https://github.com/ipclouds)
* Jan Pokorny - FIT VUTBR
* [Masaya YAMAMOTO](https://github.com/pandax381)
* [Michael Richardson](http://www.sandelman.ca/mcr)
* [Molly Miller](https://github.com/sysvinit)
* [paradon](https://github.com/paradon)
* [Philar Law](https://github.com/philar)
* [Pier Carlo Chiodi](https://pierky.com/)
* [Ricardo Salveti](https://github.com/rsalveti) - ricardo@foundries.io
* [Sander Steffann](https://github.com/steffann) - sander@steffann.nl
* [Stanislav Bogatyrev](https://github.com/realloc)
* [tbe](https://github.com/tbe)
* [techmotive](https://github.com/techmotive)
* Terry Froy
* [Tore Anderson](https://github.com/toreanderson)
* Washam Fan

==> jool_4.1.9.orig.tar.gz: jool-4.1.9/README.md <==
# Update

jool.mx is no longer maintained. Please use https://nicmx.github.io/Jool instead.

**I REPEAT: jool.mx IS (AND WILL PROBABLY FOREVER BE) OUTDATED. DO NOT QUERY IT ANYMORE. PLEASE UPDATE YOUR BOOKMARKS.**

# [Jool](https://nicmx.github.io/Jool)

An [SIIT and a NAT64](https://nicmx.github.io/Jool/en/intro-xlat.html) for Linux.

## Documentation

[See here](https://nicmx.github.io/Jool/en/documentation.html). You can also [generate the docs yourself](docs/).

You might also want to see [contact info](https://nicmx.github.io/Jool/en/contact.html).

## Credits

### NIC-Mx

* Ing. Jorge Cano Puente
* Ing. Sergio Adrián Casas Fernández - iam@sergio-casas.com
* Ing. Julio Cesar Cossio de Robles
* Ing. [Daniel Hernández Félix](https://github.com/dhfelix) - dhernandez@nic.mx
* Ing. [Alberto Leiva Popper](https://github.com/ydahhrk)
* Ing. Cristóbal Alfonso de León Benítez - cristobal.alfonso14@gmail.com
* Ing. Roberto Olivas Alarcón - roaguns@gmail.com
* Edgar Martín Rodríguez Bernal - edgarmrb_95@hotmail.com

### ITESM representatives

* Dr. Juan Arturo Nolazco - jnolazco@itesm.mx
* Ing. Martha Sordia - msordia@itesm.mx

### ITESM students

* [Abraham Baez](https://github.com/basuam) - basuam@gmail.com
* [Adrian González](https://github.com/Adrian2112) - bernardogzzf@gmail.com
* Alan Villela López - avillop@gmail.com
* [Angel Cazares](https://github.com/legionAngel) - angel.cazares@live.com
* Armando Cifuentes González - 3ncifuentesg@gmail.com
* [David Valenzuela](https://github.com/davidvrdz) - david.valenzuela.88@gmail.com
* Ing. Elvia Patricia Barrón Cano - epatybarron@gmail.com
* [Gabriel Chavez](https://github.com/chavezgu) - gabrielchavez02@gmail.com
* Jose Vicente Ramirez - pepermz@gmail.com
* [Juan Antonio Osorio](https://github.com/JAORMX) - jaosorior@gmail.com
* Juan Francisco Barragán Cantú - p.cantu12@gmail.com
* [Luis Fernando Hinojosa](https://github.com/luion) - lf.hinojosa@gmail.com
* Manuel Aude - dormam@gmail.com
* Mario Gerardo Trevinho - mario_tc88@hotmail.com
* [Miguel Alejandro González](https://github.com/magg) - maggonzz@gmail.com
* [Nixa Jayu Gpe Rodríguez Dagnino](https://github.com/NixaDagnino)
* [Ramiro Nava](https://github.com/ramironava) - ramironava@gmail.com
* [Roberto Aceves](https://github.com/robertoaceves) - roberto.aceves@gmail.com
* [Roberto Martínez Beltrán](https://github.com/ryuzak) - robmabe.92@gmail.com

### Special Thanks (contributing users)

* [airsnail](https://github.com/airsnail)
* [Andreas Urke](https://github.com/arurke)
* Andreas Rammhold
* [Dan Lüdtke](https://www.danrl.com)
* Eric Gamess
* [Hidekazu Tadokoro](https://github.com/tadokoro)
* [ipclouds](https://github.com/ipclouds)
* Jan Pokorny - FIT VUTBR
* [Masaya YAMAMOTO](https://github.com/pandax381)
* [Michael Richardson](http://www.sandelman.ca/mcr)
* [Molly Miller](https://github.com/sysvinit)
* [paradon](https://github.com/paradon)
* [Philar Law](https://github.com/philar)
* [Pier Carlo Chiodi](https://pierky.com/)
* [Ricardo Salveti](https://github.com/rsalveti) - ricardo@foundries.io
* [Sander Steffann](https://github.com/steffann) - sander@steffann.nl
* [Stanislav Bogatyrev](https://github.com/realloc)
* [tbe](https://github.com/tbe)
* [techmotive](https://github.com/techmotive)
* Terry Froy
* [Tore Anderson](https://github.com/toreanderson)
* Washam Fan

### License Disclaimer

```
Jool - SIIT and NAT64 for Linux
Copyright (C) 2023  NIC Mexico <jool@nic.mx>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
version 2, as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
```
